from DetaCache._detaCache import detaCache
from DetaCache._cacheApi import CacheApi

__version__ ='v0.0.5'
__all__=[
    'detaCache',
    'CacheApi'
]